@@ -64,6 +64,10 @@ def get_synchronization_tasks(object_name):
                     Get('update.cl_update_binhost') and 
                     Get('update.cl_update_use_migration_host') == 'off')
              },
+             {'name': 'drop_packeges_cache',
+              'method': 'Update.drop_packages_cache()',
+              'depend': AllTasks.failed_all("check_current_binhost")
+              },
              {'name': 'not_use_search:failed_base_binhost',
               'error': __("Failed to use base binhost"),
               'method': Object("delete_binhost()"),
