@@ -1889,8 +1889,6 @@ class VariableClUpdatePackageCacheSet(Variable):
         packages_fn = self.Get('cl_update_package_cache')
         gpg = self.Get('cl_update_gpg')
         packages_asc_fn = self.Get('cl_update_package_cache_sign')
-        a = path.exists(packages_fn)
-        b = path.exists(packages_asc_fn)
         if (not path.exists(packages_fn) or
             gpg and not path.exists(packages_asc_fn)):
             return "on"
